/* This file is part of the KDE project
   Copyright (C) 2001, The Karbon Developers
   Copyright (C) 2002, The Karbon Developers

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef __VTEXTCMD_H__
#define __VTEXTCMD_H__

#include <qfont.h>

#include "vshapecmd.h"

// create a text-object.

class VObject;

class VTextCmd : public VShapeCmd
{
public:
	VTextCmd( KarbonPart* part, const QFont& font, const QString& m_text );
	virtual ~VTextCmd() {}

	virtual VObject* createPath();

protected:
	QFont m_font;
	QString m_text;
};

#endif

